@@ -25,7 +25,7 @@ def pytest_addoption(parser):
 
 @pytest.fixture(scope="session")
 def root_dir():
-    return os.path.dirname(".env.credentials")
+    return os.path.dirname(os.path.abspath(".env.credentials"))
 
 
 def add_root_dir_to_path(root_dir):
